@@ -14,6 +14,7 @@
 
 #include <KCMultiDialog>
 #include <KLocalizedString>
+#include <KPluginMetaData>
 
 //__________________________________________
 int main(int argc, char *argv[])
@@ -26,8 +27,8 @@ int main(int argc, char *argv[])
 
     KCMultiDialog dialog;
     dialog.setWindowTitle(i18n("Breeze Settings"));
-    dialog.addModule(QStringLiteral("breezestyleconfig"));
-    dialog.addModule(QStringLiteral("breezedecorationconfig"));
+    dialog.addModule(KPluginMetaData(QStringLiteral("plasma/kcms/systemsettings_qwidgets/breezestyleconfig")));
+    dialog.addModule(KPluginMetaData(QStringLiteral("plasma/kcms/breeze/kcm_breezedecoration")));
     dialog.show();
 
     foreach (auto child, dialog.findChildren<QAbstractScrollArea *>()) {
